@@ -10,7 +10,7 @@ import gc
 import os
 
 from ._pre_data import _pre_data
-from ._common import _design_matrix, _leg_mt
+from ._common import _design_matrix, _leg_mt, _full_col_rank
 from ._emai import _emai
 
 
